{% load i18n %}
<h4>{% trans "Summary" %}</h4>
<table class="table table-striped">
  <tbody>
  {% for model_name, object_count in model_count %}
    <tr>
      <td>{{ model_name|capfirst }}</td>
      <td>{{ object_count }}</td>
    </tr>
  {% endfor %}
  </tbody>
</table>
