{% load i18n %}
{% load admin_urls %}

{% if has_export_permission %}
  <a href="{% url opts|admin_urlname:'export' %}{{ cl.get_query_string }}"
     class="export_link btn {{ richmin_ui.button_classes.secondary }}">
    <i class="fas fa-file-export"></i> {% trans "Export" %}
  </a>
{% endif %}
