{% extends "admin/index.html" %}
{% load i18n %}

{% block content_title %} {{ app_label|capfirst }} {% endblock %}

{% block bodyclass %}{{ block.super }} app-{{ app_label }}{% endblock %}

{% if not is_popup %}
  {% block breadcrumbs %}
    <ol class="breadcrumb">
      <li class="breadcrumb-item"><a href="{% url 'admin:index' %}">{% trans 'Home' %}</a></li>
      <li class="breadcrumb-item">{% for app in app_list %}{{ app.name }}{% endfor %}</li>
    </ol>
  {% endblock %}
{% endif %}
